<?php
namespace Creativeprofilecard;

use Creativeprofilecard\PageSettings\Page_Settings;
define( "BWDPC_ASFSK_ASSETS_PUBLIC_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/public" );
define( "BWDPC_ASFSK_ASSETS_ADMIN_DIR_FILE", plugin_dir_url( __FILE__ ) . "assets/admin" );

class ClassBWDPCProfileCard {

	private static $_instance = null;

	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	public function bwdpc_admin_editor_scripts() {
		add_filter( 'script_loader_tag', [ $this, 'bwdpc_admin_editor_scripts_as_a_module' ], 10, 2 );
	}

	public function bwdpc_admin_editor_scripts_as_a_module( $tag, $handle ) {
		if ( 'bwdpc_the_profile_card_editor' === $handle ) {
			$tag = str_replace( '<script', '<script type="module"', $tag );
		}

		return $tag;
	}

	private function include_widgets_files() {
		require_once( __DIR__ . '/widgets/bwdpc-profile-card.php' );
	}

	public function bwdpc_register_widgets() {
		// Its is now safe to include Widgets files
		$this->include_widgets_files();

		// Register Widgets
		\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new Widgets\BWDPCProfileCard() );
	}

	private function add_page_settings_controls() {
		require_once( __DIR__ . '/page-settings/bwdpc-profile-card-manager.php' );
		new Page_Settings();
	}

	// Register Category
	function bwdpc_add_elementor_widget_categories( $elements_manager ) {

		$elements_manager->add_category(
			'bwdpc-profile-card-category',
			[
				'title' => esc_html__( 'BWD Profile Card', 'bwd-Profile-card' ),
				'icon' => 'eicon-person',
			]
		);
	}
	public function bwdpc_all_assets_for_the_public(){
		wp_enqueue_style( 'bwdpc_profile_font_awesome', BWDPC_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/fontAwesome.min.css', array(), '6.5.0', 'all' );
		wp_enqueue_style( 'bwdpc_profile_card_bootstrap', BWDPC_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/bootstrap.min.css', array(), '1.0', 'all' );
		wp_enqueue_style( 'bwdpc_profile_card_style', BWDPC_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/css/style.css', array(), '1.0', 'all' );
		
		wp_enqueue_script( 'bwdpc_profile_card_interactive', BWDPC_ASFSK_ASSETS_PUBLIC_DIR_FILE . '/js/interactive.js', array('jquery'), '1.0', true );

	}
	public function bwdpc_all_assets_for_elementor_editor_admin(){
		$all_css_js_file = array(
            'bwdpc_profile_card_admin_icon_css' => array('bwdpc_path_admin_define'=>BWDPC_ASFSK_ASSETS_ADMIN_DIR_FILE . '/icon.css'),
        );
        foreach($all_css_js_file as $handle => $fileinfo){
            wp_enqueue_style( $handle, $fileinfo['bwdpc_path_admin_define'], null, '1.0', 'all');
        }
	}

	public function __construct() {
		// For public assets
		add_action('wp_enqueue_scripts', [$this, 'bwdpc_all_assets_for_the_public']);

		// For Elementor Editor
		add_action('elementor/editor/before_enqueue_scripts', [$this, 'bwdpc_all_assets_for_elementor_editor_admin']);
		
		// Register Category
		add_action( 'elementor/elements/categories_registered', [ $this, 'bwdpc_add_elementor_widget_categories' ] );

		// Register widgets
		add_action( 'elementor/widgets/widgets_registered', [ $this, 'bwdpc_register_widgets' ] );

		// Register editor scripts
		add_action( 'elementor/editor/after_enqueue_scripts', [ $this, 'bwdpc_admin_editor_scripts' ] );
		
		$this->add_page_settings_controls();
	}
}

// Instantiate Plugin Class
ClassBWDPCProfileCard::instance();